==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/pl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Wystąpił problem podczas odczytywania pliku z tego albumu",
    "Aborting preview. Could not find the file" : "Przerywanie podglądu. Nie można odnaleźć pliku",
    "Could not move \"{file}\", target exists" : "Nie można było przenieść „{file}” – plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "No compatible server found at {remote}" : "Nie znaleziono kompatybilnego serwera na {remote}",
    "Invalid server url" : "Błędny adres serwera",
    "Gallery view" : "Widok galerii",
    "Could not load the description" : "Nie można załadować opisu",
    "Could not load the description: " : "Nie można załadować opisu:",
    "Copyright" : "Prawa autorskie",
    "Could not load the copyright notice: " : "Nie można załadować noty o prawie autorskim:",
    "Copyright notice" : "Nota o prawie autorskim",
    "Link to copyright document" : "Link do dokumentu autorskiego",
    "This application may not work properly on your browser." : "Ta aplikacja może nie działać prawidłowo na twojej przeglądarce.",
    "For an improved experience, please install one of the following alternatives" : "Dla poprawy komfortu, należy zainstalować jedną z następujących alternatyw",
    "Your browser is not supported!" : "Twoja przeglądarka jest nie wspierana!",
    "please install one of the following alternatives" : "proszę zainstalować jedną z następujących alternatyw",
    "Album cannot be shown" : "Album nie może zostać wyświetlony",
    "No media files found" : "Nie znaleziono plików multimedialnych",
    "Upload pictures in the files app to display them here" : "Prześlij zdjęcia w plikach z aplikacji, aby wyświetlić je tutaj",
    "Upload new files via drag and drop or by using the [+] button above" : "Wyślij nowe pliki metodą \"przeciągnij i upuść\" lub użyj przycisku [+] powyżej",
    "Configuration error" : "Błąd konfiguracji",
    "New" : "Nowy",
    "Hide Album" : "Ukryj Album",
    "Could not hide album" : "Nie można było ukryć albumu",
    "Error loading slideshow template" : "Błąd podczas ładowania szablonu pokazu slajdów",
    "Next" : "Następny",
    "Play" : "Odtwarzaj",
    "Pause" : "Wstrzymaj",
    "Previous" : "Poprzedni",
    "Close" : "Zamknij",
    "Download" : "Pobierz",
    "Delete" : "Usuń",
    "Could not create file \"{file}\" because it already exists" : "Nie można było utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create file \"{file}\"" : "Nie można było utworzyć pliku \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "Upload" : "Wyślij",
    "Error" : "Błąd",
    "Error while sharing" : "Błąd podczas współdzielenia",
    "Error while unsharing" : "Błąd podczas zatrzymywania współdzielenia",
    "Error while changing permissions" : "Błąd przy zmianie uprawnień",
    "Shared with you and the group {group} by {owner}" : "Udostępnione tobie i grupie {group} przez {owner}",
    "Shared with you by {owner}" : "Udostępnione tobie przez {owner}",
    "Share with users or groups …" : "Współdziel z użytkownikami lub grupami",
    "Share with users, groups or remote users …" : "Współdziel z użytkownikami, grupami lub użytkownikami zdalnymi ...",
    "Share" : "Udostępnij",
    "Share link" : "Udostępnij link",
    "The public link will expire no later than {days} days after it is created" : "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
    "Link" : "Link",
    "Password protect" : "Zabezpiecz hasłem",
    "Password" : "Hasło",
    "Choose a password for the public link" : "Wybierz hasło dla linku publicznego",
    "Allow editing" : "Pozwól na edycję",
    "Email link to person" : "Wyślij osobie odnośnik poprzez e-mail",
    "Send" : "Wyślij",
    "Set expiration date" : "Ustaw datę wygaśnięcia",
    "Expiration" : "Wygaśnięcie",
    "Expiration date" : "Data wygaśnięcia",
    "An error occured. Please try again" : "Wystąpił błąd. Proszę spróbować ponownie.",
    "Adding user..." : "Dodawanie użytkownika...",
    "group" : "grupa",
    "remote" : "zdalny",
    "Resharing is not allowed" : "Współdzielenie nie jest możliwe",
    "Unshare" : "Zatrzymaj współdzielenie",
    "notify by email" : "powiadom przez emaila",
    "can share" : "może współdzielić",
    "can edit" : "może edytować",
    "access control" : "kontrola dostępu",
    "create" : "utwórz",
    "change" : "zmiany",
    "delete" : "skasuj",
    "Password protected" : "Zabezpieczone hasłem",
    "Error unsetting expiration date" : "Błąd podczas usuwania daty wygaśnięcia",
    "Error setting expiration date" : "Błąd podczas ustawiania daty wygaśnięcia",
    "Sending ..." : "Wysyłanie...",
    "Email sent" : "E-mail wysłany",
    "Warning" : "Ostrzeżenie",
    "This share is password-protected" : "Udział ten jest chroniony hasłem",
    "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
    "Sort by date" : "Sortuj według daty",
    "Sort by name" : "Sortuj według nazwy",
    "Cancel upload" : "Anuluj wysyłanie",
    "Album information" : "Inormacje o albumie",
    "File list" : "Lista plików",
    "Sorry, this file could not be found." : "Przepraszamy, ten plik nie został odnaleziony.",
    "Reasons might be:" : "Możliwe powody:",
    "the file was removed" : "plik został usunięty",
    "the file is corrupt" : "plik jest uszkodzony",
    "the encryption key is missing" : "brakujący klucz szyfrowania",
    "Possible reasons for the problem:" : "Możliwe przyczyny tego problemu:",
    "For more information, please contact your friendly ownCloud administrator." : "Po więcej informacji, proszę skontaktuj się z twoim przyjaznym administratorem ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
    "the item was removed" : "element został usunięty",
    "the link has expired" : "link wygasł",
    "sharing is disabled" : "udostępnianie jest wyłączone",
    "Add to your Nextcloud" : "Dodaj do swojego Nextcloud",
    "Picture view" : "Widok zdjęć"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/pl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeria",
    "There was a problem reading files from this album" : "Wystąpił problem podczas odczytywania pliku z tego albumu",
    "Aborting preview. Could not find the file" : "Przerywanie podglądu. Nie można odnaleźć pliku",
    "Could not move \"{file}\", target exists" : "Nie można było przenieść „{file}” – plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "No compatible server found at {remote}" : "Nie znaleziono kompatybilnego serwera na {remote}",
    "Invalid server url" : "Błędny adres serwera",
    "Could not load the description" : "Nie można załadować opisu",
    "Could not load the description: " : "Nie można załadować opisu:",
    "Copyright" : "Prawa autorskie",
    "Could not load the copyright notice: " : "Nie można załadować noty o prawie autorskim:",
    "Copyright notice" : "Nota o prawie autorskim",
    "Link to copyright document" : "Link do dokumentu o prawach autorskich",
    "This application may not work properly on your browser." : "Ta aplikacja może nie działać prawidłowo na twojej przeglądarce.",
    "For an improved experience, please install one of the following alternatives" : "Dla poprawy komfortu, należy zainstalować jedną z następujących alternatyw",
    "Your browser is not supported!" : "Twoja przeglądarka jest nie wspierana!",
    "please install one of the following alternatives" : "proszę zainstalować jedną z następujących alternatyw",
    "Album cannot be shown" : "Album nie może zostać wyświetlony",
    "No media files found" : "Nie znaleziono plików multimedialnych",
    "Upload new files via drag and drop or by using the [+] button above" : "Wyślij nowe pliki metodą \"przeciągnij i upuść\" lub użyj przycisku [+] powyżej",
    "Configuration error" : "Błąd konfiguracji",
    "New" : "Nowy",
    "Hide Album" : "Ukryj Album",
    "Could not hide album" : "Nie można było ukryć albumu",
    "Error loading slideshow template" : "Błąd podczas ładowania szablonu pokazu slajdów",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Błąd!</strong> Nie moge wygenerować podglądu tego pliku.<br>Proszę idź do następnego slajdu podczas gdy usuniemy ten obiekt z pokazu slajdów",
    "Next" : "Następny",
    "Play" : "Odtwarzaj",
    "Pause" : "Wstrzymaj",
    "Previous" : "Poprzedni",
    "Close" : "Zamknij",
    "Download" : "Pobierz",
    "Toggle background" : "Przełącz tło",
    "Delete" : "Usuń",
    "Could not create file \"{file}\" because it already exists" : "Nie można było utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create file \"{file}\"" : "Nie można było utworzyć pliku \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie jest dozwolonym typem pliku",
    "Upload" : "Wyślij",
    "Error" : "Błąd",
    "Error while sharing" : "Błąd podczas współdzielenia",
    "Error while unsharing" : "Błąd podczas zatrzymywania współdzielenia",
    "Error while changing permissions" : "Błąd przy zmianie uprawnień",
    "Shared with you and the group {group} by {owner}" : "Udostępnione tobie i grupie {group} przez {owner}",
    "Shared with you by {owner}" : "Udostępnione tobie przez {owner}",
    "Share with users or groups …" : "Współdziel z użytkownikami lub grupami",
    "Share with users, groups or remote users …" : "Współdziel z użytkownikami, grupami lub użytkownikami zdalnymi ...",
    "Share" : "Udostępnij",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Współdziel z użytkownikami z innych serwerów, używając ich ID Stowarzyszonej Chmury username@example.com/cloud",
    "Share link" : "Udostępnij link",
    "The public link will expire no later than {days} days after it is created" : "Link publiczny wygaśnie nie później niż po {days} dniach od utworzenia",
    "Link" : "Link",
    "Password protect" : "Zabezpiecz hasłem",
    "Password" : "Hasło",
    "Choose a password for the public link" : "Wybierz hasło dla linku publicznego",
    "Allow editing" : "Pozwól na edycję",
    "Email link to person" : "Wyślij osobie odnośnik poprzez e-mail",
    "Send" : "Wyślij",
    "Set expiration date" : "Ustaw datę wygaśnięcia",
    "Expiration" : "Wygaśnięcie",
    "Expiration date" : "Data wygaśnięcia",
    "This list is maybe truncated - please refine your search term to see more results." : "Ta lista może być obcięta - proszę bardziej określić fraze wyszukiwania, aby zobaczyć więcej wyników.",
    "No users or groups found for {search}" : "Nie znaleziono użytkownika lub grupy {search}",
    "No users found for {search}" : "Nie znaleziono użytkownika {search}",
    "An error occured. Please try again" : "Wystąpił błąd. Proszę spróbować ponownie.",
    "Adding user..." : "Dodawanie użytkownika...",
    "group" : "grupa",
    "remote" : "zdalny",
    "Resharing is not allowed" : "Współdzielenie nie jest możliwe",
    "Error while retrieving shares" : "Błąd podczas zaczytywania obiektów współdzielonych",
    "Unshare" : "Zatrzymaj współdzielenie",
    "notify by email" : "powiadom przez emaila",
    "can share" : "może współdzielić",
    "can edit" : "może edytować",
    "access control" : "kontrola dostępu",
    "create" : "utwórz",
    "change" : "zmiany",
    "delete" : "skasuj",
    "Password protected" : "Zabezpieczone hasłem",
    "Error unsetting expiration date" : "Błąd podczas usuwania daty wygaśnięcia",
    "Error setting expiration date" : "Błąd podczas ustawiania daty wygaśnięcia",
    "Sending ..." : "Wysyłanie...",
    "Email sent" : "E-mail wysłany",
    "Warning" : "Ostrzeżenie",
    "This share is password-protected" : "Udział ten jest chroniony hasłem",
    "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
    "Sort by date" : "Sortuj według daty",
    "Sort by name" : "Sortuj według nazwy",
    "Cancel upload" : "Anuluj wysyłanie",
    "Album information" : "Inormacje o albumie",
    "File list" : "Lista plików",
    "Sorry, this file could not be found." : "Przepraszamy, ten plik nie został odnaleziony.",
    "Reasons might be:" : "Możliwe powody:",
    "the wrong file ID was provided" : "wprowadzono nie właściwy ID pliku",
    "the file was removed" : "plik został usunięty",
    "the file is corrupt" : "plik jest uszkodzony",
    "the encryption key is missing" : "brakujący klucz szyfrowania",
    "Here is the error message returned by the server: " : "To jest informacja zwrotna od serwera:",
    "For more information, please contact your friendly Nextcloud administrator." : "Skontaktuj się ze swoim administratorem Nextcloud, żeby uzyskać więcej informacji.",
    "Sorry, but the server could not fulfill your request." : "Przepraszam, ale serwer nie może spełnić twojego żądania.",
    "Possible reasons for the problem:" : "Możliwe przyczyny tego problemu:",
    "a conflicting app was installed" : "Została zainstalowana kolidująca aplikacja",
    "a required component is missing or was disconnected" : "brak wymaganego komponentu lub został on rozłączony",
    "the filesystem is not readable" : "system plików jest nie czytelny",
    "Sorry, this link doesn't seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
    "the item was removed" : "element został usunięty",
    "the link has expired" : "link wygasł",
    "sharing is disabled" : "udostępnianie jest wyłączone",
    "For more information, please ask the person who has sent you this link." : "Po więcej informacji, proszę skontaktuj się z osobą, która wysłała Tobie ten link.",
    "Add to your Nextcloud" : "Dodaj do swojego Nextcloud",
    "Picture view" : "Widok zdjęć",
    "Gallery view" : "Widok galerii"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
